@@ -156,16 +156,16 @@ class Manifest(object):
         return False
 
     def list_objects(self, s, p):
-        s_uri = self.uh.parse_uri(s)
-        if s_uri in self.items_rdfobjects:
-            return self.items_rdfobjects[s_uri].list_objects(p)
-        elif s == "*":
+        if s == "*":
             construct = {}
             for s_uri in self.items_rdfobjects.keys():
                 objs = self.items_rdfobjects[s_uri].list_objects(p)
                 if objs:
                     construct[s_uri] = objs
-            return contruct
+            return construct
+        s_uri = self.uh.parse_uri(s)
+        if s_uri in self.items_rdfobjects:
+            return self.items_rdfobjects[s_uri].list_objects(p)
         return []
 
     @_altered_flag
